@@ -26,7 +26,14 @@ def send_notification(api_key, text, device_id=None, device_ids=None, device_nam
     if device_id: req_url += "&deviceId=" + device_id
     if device_ids: req_url += "&deviceIds=" + device_ids
     if device_names: req_url += "&deviceNames=" + device_names
-    if actions: req_url += "&actions=" + "|||".join(actions)
+    if actions:
+        action_strings = []
+        for action in actions:
+            action_str = action
+            if actions[action]:
+                action_str += "=:=" + "=:=".join(actions[action])
+            action_strings.append(action_str)
+        req_url += "&actions=" + "|||".join(action_strings)
     requests.get(req_url)
 
 def ring_device(api_key, device_id=None, device_ids=None, device_names=None):
